.. toctree::
   self

.. mdinclude:: ../README.md

Architecture overview
---------------------
This diagram gives a quick overview on a conceptual level how different concepts
are related.

.. image:: /images/overview.svg
   :alt: Architecture overview
   :align: center

|

The API documentation
-----------------------------

If you are looking for information on a specific function, class, or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 3

   api
